@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.filter.ipcut import _ipcut
 
 
-class TestIpCut(unittest.TestCase):
+class TestIpCut(TestCase):
     def setUp(self):
         pass
 
