@@ -7,6 +7,7 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
+import json
 import os
 import re
 import shutil
@@ -16,6 +17,7 @@ from collections import namedtuple
 
 from ansible.module_utils.basic import missing_required_lib
 from ansible.module_utils.common.text.converters import to_native
+from ansible.module_utils.six import string_types
 from ansible.module_utils.six.moves import shlex_quote
 
 from ansible_collections.community.docker.plugins.module_utils.util import DockerBaseClass
@@ -84,6 +86,7 @@ DOCKER_STATUS_WAITING = frozenset((
     'Waiting',
 ))
 DOCKER_STATUS = frozenset(DOCKER_STATUS_DONE | DOCKER_STATUS_WORKING | DOCKER_STATUS_PULL | DOCKER_STATUS_ERROR | DOCKER_STATUS_WAITING)
+DOCKER_STATUS_AND_WARNING = frozenset(DOCKER_STATUS | DOCKER_STATUS_WARNING)
 
 DOCKER_PULL_PROGRESS_DONE = frozenset((
     'Already exists',
@@ -202,9 +205,9 @@ _RE_SKIPPED_EVENT = re.compile(
     r'\s*'
     r'(?P<resource_id>\S+)'
     r'\s+'
-    r'Skipped -'
+    r'Skipped(?: -'
     r'\s*'
-    r'(?P<msg>\S(?:|.*\S))'
+    r'(?P<msg>\S(?:|.*\S))|\s*)'
     r'$'
 )
 
@@ -348,13 +351,118 @@ def _concat_event_msg(event, append_msg):
     )
 
 
-def parse_events(stderr, dry_run=False, warn_function=None):
+_JSON_LEVEL_TO_STATUS_MAP = {
+    'warning': 'Warning',
+    'error': 'Error',
+}
+
+
+def parse_json_events(stderr, warn_function=None):
+    events = []
+    stderr_lines = stderr.splitlines()
+    if stderr_lines and stderr_lines[-1] == b'':
+        del stderr_lines[-1]
+    for line in stderr_lines:
+        line = line.strip()
+        if not line.startswith(b'{') or not line.endswith(b'}'):
+            if line.startswith(b'Warning: '):
+                # This is a bug in Compose that will get fixed by https://github.com/docker/compose/pull/11996
+                event = Event(
+                    ResourceType.UNKNOWN,
+                    None,
+                    'Warning',
+                    to_native(line[len(b'Warning: '):]),
+                )
+                events.append(event)
+                continue
+            if warn_function:
+                warn_function(
+                    'Cannot parse event from non-JSON line: {0!r}. Please report this at '
+                    'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                    .format(line)
+                )
+            continue
+        try:
+            line_data = json.loads(line)
+        except Exception as exc:
+            if warn_function:
+                warn_function(
+                    'Cannot parse event from line: {0!r}: {1}. Please report this at '
+                    'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                    .format(line, exc)
+                )
+            continue
+        if line_data.get('tail'):
+            resource_type = ResourceType.UNKNOWN
+            msg = line_data.get('text')
+            status = 'Error'
+            if isinstance(msg, str) and msg.lower().startswith('warning:'):
+                # For some reason, Writer.TailMsgf() is always used for errors *except* in one place,
+                # where its message is prepended with 'WARNING: ' (in pkg/compose/pull.go).
+                status = 'Warning'
+                msg = msg[len('warning:'):].lstrip()
+            event = Event(
+                resource_type,
+                None,
+                status,
+                msg,
+            )
+        elif line_data.get('error'):
+            resource_type = ResourceType.UNKNOWN
+            event = Event(
+                resource_type,
+                line_data.get('id'),
+                'Error',
+                line_data.get('message'),
+            )
+        else:
+            resource_type = ResourceType.UNKNOWN
+            resource_id = line_data.get('id')
+            status = line_data.get('status')
+            text = line_data.get('text')
+            if isinstance(resource_id, str) and ' ' in resource_id:
+                resource_type_str, resource_id = resource_id.split(' ', 1)
+                try:
+                    resource_type = ResourceType.from_docker_compose_event(resource_type_str)
+                except KeyError:
+                    if warn_function:
+                        warn_function(
+                            'Unknown resource type {0!r} in line {1!r}. Please report this at '
+                            'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                            .format(resource_type_str, line)
+                        )
+                    resource_type = ResourceType.UNKNOWN
+            elif text in DOCKER_STATUS_PULL:
+                resource_type = ResourceType.IMAGE
+                status, text = text, status
+            elif text in DOCKER_PULL_PROGRESS_DONE or line_data.get('text') in DOCKER_PULL_PROGRESS_WORKING:
+                resource_type = ResourceType.IMAGE_LAYER
+                status, text = text, status
+            elif status is None and isinstance(text, string_types) and text.startswith('Skipped - '):
+                status, text = text.split(' - ', 1)
+            elif line_data.get('level') in _JSON_LEVEL_TO_STATUS_MAP and 'msg' in line_data:
+                status = _JSON_LEVEL_TO_STATUS_MAP[line_data['level']]
+                text = line_data['msg']
+            if status not in DOCKER_STATUS_AND_WARNING and text in DOCKER_STATUS_AND_WARNING:
+                status, text = text, status
+            event = Event(
+                resource_type,
+                resource_id,
+                status,
+                text,
+            )
+
+        events.append(event)
+    return events
+
+
+def parse_events(stderr, dry_run=False, warn_function=None, nonzero_rc=False):
     events = []
     error_event = None
     stderr_lines = stderr.splitlines()
     if stderr_lines and stderr_lines[-1] == b'':
         del stderr_lines[-1]
-    for line in stderr_lines:
+    for index, line in enumerate(stderr_lines):
         line = to_native(line.strip())
         if not line:
             continue
@@ -385,7 +493,7 @@ def parse_events(stderr, dry_run=False, warn_function=None):
             index_event = _find_last_event_for(events, match.group('resource_id'))
             if index_event is not None:
                 index, event = index_event
-                events[-1] = _concat_event_msg(event, match.group('msg'))
+                events[index] = _concat_event_msg(event, match.group('msg'))
         event, parsed = _extract_logfmt_event(line, warn_function=warn_function)
         if event is not None:
             events.append(event)
@@ -405,7 +513,7 @@ def parse_events(stderr, dry_run=False, warn_function=None):
             )
             events.append(error_event)
             continue
-        if len(stderr_lines) == 1:
+        if len(stderr_lines) == 1 or (nonzero_rc and index == len(stderr_lines) - 1):
             # **Very likely** an error message that is independent of an error event
             error_event = Event(
                 ResourceType.UNKNOWN,
@@ -456,7 +564,7 @@ def extract_actions(events):
 def emit_warnings(events, warn_function):
     for event in events:
         # If a message is present, assume it is a warning
-        if event.status is None and event.msg is not None:
+        if (event.status is None and event.msg is not None) or event.status in DOCKER_STATUS_WARNING:
             warn_function('Docker compose: {resource_type} {resource_id}: {msg}'.format(
                 resource_type=event.resource_type,
                 resource_id=event.resource_id,
@@ -476,11 +584,15 @@ def update_failed(result, events, args, stdout, stderr, rc, cli):
     errors = []
     for event in events:
         if event.status in DOCKER_STATUS_ERROR:
-            msg = 'Error when processing {resource_type} {resource_id}: '
-            if event.resource_type == 'unknown':
-                msg = 'Error when processing {resource_id}: '
-                if event.resource_id == '':
-                    msg = 'General error: '
+            if event.resource_id is None:
+                if event.resource_type == 'unknown':
+                    msg = 'General error: ' if event.resource_type == 'unknown' else 'Error when processing {resource_type}: '
+            else:
+                msg = 'Error when processing {resource_type} {resource_id}: '
+                if event.resource_type == 'unknown':
+                    msg = 'Error when processing {resource_id}: '
+                    if event.resource_id == '':
+                        msg = 'General error: '
             msg += '{status}' if event.msg is None else '{msg}'
             errors.append(msg.format(
                 resource_type=event.resource_type,
@@ -598,13 +710,19 @@ class BaseComposeManager(DockerBaseClass):
             filenames = ', '.join(DOCKER_COMPOSE_FILES[:-1])
             self.fail('"{0}" does not contain {1}, or {2}'.format(self.project_src, filenames, DOCKER_COMPOSE_FILES[-1]))
 
+        # Support for JSON output was added in Compose 2.29.0 (https://github.com/docker/compose/releases/tag/v2.29.0);
+        # more precisely in https://github.com/docker/compose/pull/11478
+        self.use_json_events = self.compose_version >= LooseVersion('2.29.0')
+
     def fail(self, msg, **kwargs):
         self.cleanup()
         self.client.fail(msg, **kwargs)
 
-    def get_base_args(self):
+    def get_base_args(self, plain_progress=False):
         args = ['compose', '--ansi', 'never']
-        if self.compose_version >= LooseVersion('2.19.0'):
+        if self.use_json_events and not plain_progress:
+            args.extend(['--progress', 'json'])
+        elif self.compose_version >= LooseVersion('2.19.0'):
             # https://github.com/docker/compose/pull/10690
             args.extend(['--progress', 'plain'])
         args.extend(['--project-directory', self.project_src])
@@ -618,17 +736,25 @@ class BaseComposeManager(DockerBaseClass):
             args.extend(['--profile', profile])
         return args
 
+    def _handle_failed_cli_call(self, args, rc, stdout, stderr):
+        events = parse_json_events(stderr, warn_function=self.client.warn)
+        result = {}
+        self.update_failed(result, events, args, stdout, stderr, rc)
+        self.client.module.exit_json(**result)
+
     def list_containers_raw(self):
         args = self.get_base_args() + ['ps', '--format', 'json', '--all']
         if self.compose_version >= LooseVersion('2.23.0'):
             # https://github.com/docker/compose/pull/11038
             args.append('--no-trunc')
-        kwargs = dict(cwd=self.project_src, check_rc=True)
+        kwargs = dict(cwd=self.project_src, check_rc=not self.use_json_events)
         if self.compose_version >= LooseVersion('2.21.0'):
             # Breaking change in 2.21.0: https://github.com/docker/compose/pull/10918
-            dummy, containers, dummy = self.client.call_cli_json_stream(*args, **kwargs)
+            rc, containers, stderr = self.client.call_cli_json_stream(*args, **kwargs)
         else:
-            dummy, containers, dummy = self.client.call_cli_json(*args, **kwargs)
+            rc, containers, stderr = self.client.call_cli_json(*args, **kwargs)
+        if self.use_json_events and rc != 0:
+            self._handle_failed_cli_call(args, rc, containers, stderr)
         return containers
 
     def list_containers(self):
@@ -648,12 +774,16 @@ class BaseComposeManager(DockerBaseClass):
 
     def list_images(self):
         args = self.get_base_args() + ['images', '--format', 'json']
-        kwargs = dict(cwd=self.project_src, check_rc=True)
-        dummy, images, dummy = self.client.call_cli_json(*args, **kwargs)
+        kwargs = dict(cwd=self.project_src, check_rc=not self.use_json_events)
+        rc, images, stderr = self.client.call_cli_json(*args, **kwargs)
+        if self.use_json_events and rc != 0:
+            self._handle_failed_cli_call(args, rc, images, stderr)
         return images
 
-    def parse_events(self, stderr, dry_run=False):
-        return parse_events(stderr, dry_run=dry_run, warn_function=self.client.warn)
+    def parse_events(self, stderr, dry_run=False, nonzero_rc=False):
+        if self.use_json_events:
+            return parse_json_events(stderr, warn_function=self.client.warn)
+        return parse_events(stderr, dry_run=dry_run, warn_function=self.client.warn, nonzero_rc=nonzero_rc)
 
     def emit_warnings(self, events):
         emit_warnings(events, warn_function=self.client.warn)
