@@ -32,6 +32,7 @@ TC_FORMATS = dict(
     simple_opt_val__int=(partial(cmd_runner_fmt.as_opt_val, "-t"), 42, ["-t", "42"], None),
     simple_opt_eq_val__str=(partial(cmd_runner_fmt.as_opt_eq_val, "--food"), "potatoes", ["--food=potatoes"], None),
     simple_opt_eq_val__int=(partial(cmd_runner_fmt.as_opt_eq_val, "--answer"), 42, ["--answer=42"], None),
+    simple_list_empty=(cmd_runner_fmt.as_list, [], [], None),
     simple_list_potato=(cmd_runner_fmt.as_list, "literal_potato", ["literal_potato"], None),
     simple_list_42=(cmd_runner_fmt.as_list, 42, ["42"], None),
     simple_list_min_len_ok=(partial(cmd_runner_fmt.as_list, min_len=1), 42, ["42"], None),
@@ -358,7 +359,7 @@ def test_runner_context(runner_input, cmd_execution, expected):
     )
 
     def _assert_run_info(actual, expected):
-        reduced = dict((k, actual[k]) for k in expected.keys())
+        reduced = {k: actual[k] for k in expected.keys()}
         assert reduced == expected, "{0}".format(reduced)
 
     def _assert_run(runner_input, cmd_execution, expected, ctx, results):
