@@ -5,6 +5,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -222,59 +223,53 @@ EXAMPLES = r'''
 RETURN = r'''
 name:
   description: Index name.
-  returned: always
+  returned: success
   type: str
   sample: 'foo_idx'
 state:
   description: Index state.
-  returned: always
+  returned: success
   type: str
   sample: 'present'
 schema:
   description: Schema where index exists.
-  returned: always
+  returned: success
   type: str
   sample: 'public'
 tablespace:
   description: Tablespace where index exists.
-  returned: always
+  returned: success
   type: str
   sample: 'ssd'
 query:
   description: Query that was tried to be executed.
-  returned: always
+  returned: success
   type: str
   sample: 'CREATE INDEX CONCURRENTLY foo_idx ON test_table USING BTREE (id)'
 storage_params:
   description: Index storage parameters.
-  returned: always
+  returned: success
   type: list
   sample: [ "fillfactor=90" ]
 valid:
   description: Index validity.
-  returned: always
+  returned: success
   type: bool
   sample: true
 '''
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
-
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import check_input
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
-    exec_sql,
     ensure_required_libs,
+    exec_sql,
     get_conn_params,
+    pg_cursor_args,
     postgres_common_argument_spec,
 )
 
-
 VALID_IDX_TYPES = ('BTREE', 'HASH', 'GIST', 'SPGIST', 'GIN', 'BRIN')
 
 
@@ -294,13 +289,13 @@ class Index(object):
 
     Args:
         module (AnsibleModule) -- object of AnsibleModule class
-        cursor (cursor) -- cursor object of psycopg2 library
+        cursor (cursor) -- cursor object of psycopg library
         schema (str) -- name of the index schema
         name (str) -- name of the index
 
     Attrs:
         module (AnsibleModule) -- object of AnsibleModule class
-        cursor (cursor) -- cursor object of psycopg2 library
+        cursor (cursor) -- cursor object of psycopg library
         schema (str) -- name of the index schema
         name (str) -- name of the index
         exists (bool) -- flag the index exists in the DB or not
@@ -349,19 +344,20 @@ class Index(object):
                  "ON i.indexname = c.relname "
                  "JOIN pg_catalog.pg_index AS pi "
                  "ON c.oid = pi.indexrelid "
-                 "WHERE i.indexname = %(name)s")
+                 "WHERE i.schemaname = %(schema)s "
+                 "AND i.indexname = %(name)s")
 
-        res = exec_sql(self, query, query_params={'name': self.name}, add_to_executed=False)
+        res = exec_sql(self, query, query_params={'schema': self.schema, 'name': self.name}, add_to_executed=False)
         if res:
             self.exists = True
             self.info = dict(
                 name=self.name,
                 state='present',
-                schema=res[0][0],
-                tblname=res[0][1],
-                tblspace=res[0][2] if res[0][2] else '',
-                valid=res[0][3],
-                storage_params=res[0][4] if res[0][4] else [],
+                schema=res[0]["schemaname"],
+                tblname=res[0]["tablename"],
+                tblspace=res[0]["tablespace"] if res[0]["tablespace"] else '',
+                valid=res[0]["indisvalid"],
+                storage_params=res[0]["reloptions"] if res[0]["reloptions"] else [],
             )
             return True
 
@@ -520,11 +516,11 @@ def main():
     if cascade and state != 'absent':
         module.fail_json(msg="cascade parameter used only with state=absent")
 
-    # Ensure psycopg2 libraries are available before connecting to DB:
+    # Ensure psycopg libraries are available before connecting to DB:
     ensure_required_libs(module)
     conn_params = get_conn_params(module, module.params)
     db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-    cursor = db_connection.cursor(cursor_factory=DictCursor)
+    cursor = db_connection.cursor(**pg_cursor_args)
 
     # Set defaults:
     changed = False
