@@ -9,30 +9,27 @@ __metaclass__ = type
 import json
 import pytest
 import sys
-try:
-    from requests import Response
-except ImportError:
-    if sys.version_info < (2, 7):
-        pytestmark = pytest.mark.skip('Skipping Unit Tests on 2.6 as requests is not available')
-    else:
-        raise
 
+import ansible_collections.netapp.storagegrid.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.storagegrid.tests.unit.compat import unittest
-from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import (
-    patch,
-    Mock,
-)
+from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import patch
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.storagegrid.plugins.modules.na_sg_grid_certificate import (
     SgGridCertificate as grid_certificate_module,
 )
 
+if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
+    pytestmark = pytest.mark.skip("Skipping Unit Tests on 2.6 as requests is not available")
+
 # REST API canned responses when mocking send_request
 SRR = {
     # common responses
     "empty_good": ({"data": []}, None),
-    "not_found": ({"status": "error", "code": 404, "data": {}}, {"key": "error.404"},),
+    "not_found": (
+        {"status": "error", "code": 404, "data": {}},
+        {"key": "error.404"},
+    ),
     "end_of_sequence": (None, "Unexpected call to send_request"),
     "generic_error": (None, "Expected error"),
     "delete_good": (None, None),
@@ -127,7 +124,7 @@ def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
 
 
 class TestMyModule(unittest.TestCase):
-    """ a group of related Unit Tests """
+    """a group of related Unit Tests"""
 
     def setUp(self):
         self.mock_module_helper = patch.multiple(basic.AnsibleModule, exit_json=exit_json, fail_json=fail_json)
@@ -264,14 +261,14 @@ class TestMyModule(unittest.TestCase):
         )
 
     def test_module_fail_when_required_args_missing(self):
-        """ required arguments are reported as errors """
+        """required arguments are reported as errors"""
         with pytest.raises(AnsibleFailJson) as exc:
             set_module_args(self.set_default_args_fail_check())
             grid_certificate_module()
         print("Info: test_module_fail_when_required_args_missing: %s" % exc.value.args[0]["msg"])
 
     def test_module_pass_when_required_args_present(self):
-        """ required arguments are reported as errors """
+        """required arguments are reported as errors"""
         with pytest.raises(AnsibleExitJson) as exc:
             set_module_args(self.set_default_args_pass_check())
             grid_certificate_module()
