@@ -9,30 +9,27 @@ __metaclass__ = type
 import json
 import pytest
 import sys
-try:
-    from requests import Response
-except ImportError:
-    if sys.version_info < (2, 7):
-        pytestmark = pytest.mark.skip('Skipping Unit Tests on 2.6 as requests is not available')
-    else:
-        raise
 
+import ansible_collections.netapp.storagegrid.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.storagegrid.tests.unit.compat import unittest
-from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import (
-    patch,
-    Mock,
-)
+from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import patch
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.storagegrid.plugins.modules.na_sg_grid_user import (
     SgGridUser as grid_user_module,
 )
 
+if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
+    pytestmark = pytest.mark.skip("Skipping Unit Tests on 2.6 as requests is not available")
+
 # REST API canned responses when mocking send_request
 SRR = {
     # common responses
     "empty_good": ({"data": []}, None),
-    "not_found": ({"status": "error", "code": 404, "data": {}}, {"key": "error.404"},),
+    "not_found": (
+        {"status": "error", "code": 404, "data": {}},
+        {"key": "error.404"},
+    ),
     "end_of_sequence": (None, "Unexpected call to send_request"),
     "generic_error": (None, "Expected error"),
     "delete_good": ({"code": 204}, None),
@@ -159,12 +156,10 @@ def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
 
 
 class TestMyModule(unittest.TestCase):
-    """ a group of related Unit Tests """
+    """a group of related Unit Tests"""
 
     def setUp(self):
-        self.mock_module_helper = patch.multiple(
-            basic.AnsibleModule, exit_json=exit_json, fail_json=fail_json
-        )
+        self.mock_module_helper = patch.multiple(basic.AnsibleModule, exit_json=exit_json, fail_json=fail_json)
         self.mock_module_helper.start()
         self.addCleanup(self.mock_module_helper.stop)
 
@@ -227,37 +222,29 @@ class TestMyModule(unittest.TestCase):
         )
 
     def test_module_fail_when_required_args_missing(self):
-        """ required arguments are reported as errors """
+        """required arguments are reported as errors"""
         with pytest.raises(AnsibleFailJson) as exc:
             set_module_args(self.set_default_args_fail_check())
             grid_user_module()
-        print(
-            "Info: test_module_fail_when_required_args_missing: %s"
-            % exc.value.args[0]["msg"]
-        )
+        print("Info: test_module_fail_when_required_args_missing: %s" % exc.value.args[0]["msg"])
 
     def test_module_fail_when_required_args_present(self):
-        """ required arguments are reported as errors """
+        """required arguments are reported as errors"""
         with pytest.raises(AnsibleExitJson) as exc:
             set_module_args(self.set_default_args_pass_check())
             grid_user_module()
             exit_json(changed=True, msg="Induced arguments check")
-        print(
-            "Info: test_module_fail_when_required_args_present: %s"
-            % exc.value.args[0]["msg"]
-        )
+        print("Info: test_module_fail_when_required_args_present: %s" % exc.value.args[0]["msg"])
         assert exc.value.args[0]["changed"]
 
     def test_module_fail_with_bad_unique_name(self):
-        """ error returned if unique_name doesn't start with user or federated_user """
+        """error returned if unique_name doesn't start with user or federated_user"""
         with pytest.raises(AnsibleFailJson) as exc:
             args = self.set_default_args_pass_check()
             args["unique_name"] = "noprefixuser"
             set_module_args(args)
             grid_user_module()
-        print(
-            "Info: test_module_fail_with_bad_unique_name: %s" % exc.value.args[0]["msg"]
-        )
+        print("Info: test_module_fail_with_bad_unique_name: %s" % exc.value.args[0]["msg"])
 
     def set_args_create_na_sg_grid_user_with_password(self):
         return dict(
@@ -273,9 +260,7 @@ class TestMyModule(unittest.TestCase):
             }
         )
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_create_na_sg_grid_user_no_group_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_grid_user_no_group())
         my_obj = grid_user_module()
@@ -286,15 +271,10 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_create_na_sg_grid_user_no_group_pass: %s"
-            % repr(exc.value.args[0])
-        )
+        print("Info: test_create_na_sg_grid_user_no_group_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_create_na_sg_grid_user_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_grid_user())
         my_obj = grid_user_module()
@@ -309,9 +289,7 @@ class TestMyModule(unittest.TestCase):
         print("Info: test_create_na_sg_grid_user_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_idempotent_create_na_sg_grid_user_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_grid_user())
         my_obj = grid_user_module()
@@ -322,15 +300,10 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_idempotent_create_na_sg_grid_user_pass: %s"
-            % repr(exc.value.args[0])
-        )
+        print("Info: test_idempotent_create_na_sg_grid_user_pass: %s" % repr(exc.value.args[0]))
         assert not exc.value.args[0]["changed"]
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_update_na_sg_grid_user_pass(self, mock_request):
         args = self.set_args_create_na_sg_grid_user()
         args["member_of"] = ["group/testgridgroup1", "group/testgridgroup2"]
@@ -348,9 +321,7 @@ class TestMyModule(unittest.TestCase):
         print("Info: test_update_na_sg_grid_user_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_delete_na_sg_grid_user_pass(self, mock_request):
         set_module_args(self.set_args_delete_na_sg_grid_user())
         my_obj = grid_user_module()
@@ -366,9 +337,7 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]["changed"]
 
     # create user and set pass
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_create_na_sg_grid_user_and_set_password_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_grid_user_with_password())
         my_obj = grid_user_module()
@@ -381,19 +350,12 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_create_na_sg_grid_user_and_set_password_pass: %s"
-            % repr(exc.value.args[0])
-        )
+        print("Info: test_create_na_sg_grid_user_and_set_password_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
     # Idempotent user with password defined
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
-    def test_idempotent_create_na_sg_grid_user_and_set_password_pass(
-        self, mock_request
-    ):
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_idempotent_create_na_sg_grid_user_and_set_password_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_grid_user_with_password())
         my_obj = grid_user_module()
         mock_request.side_effect = [
@@ -403,16 +365,11 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_idempotent_create_na_sg_grid_user_and_set_password_pass: %s"
-            % repr(exc.value.args[0])
-        )
+        print("Info: test_idempotent_create_na_sg_grid_user_and_set_password_pass: %s" % repr(exc.value.args[0]))
         assert not exc.value.args[0]["changed"]
 
     # update user and set pass
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_update_na_sg_grid_user_and_set_password_pass(self, mock_request):
         args = self.set_args_create_na_sg_grid_user_with_password()
         args["member_of"] = ["group/testgridgroup1", "group/testgridgroup2"]
@@ -429,17 +386,12 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_update_na_sg_grid_user_and_set_password_pass: %s"
-            % repr(exc.value.args[0])
-        )
+        print("Info: test_update_na_sg_grid_user_and_set_password_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
     # set pass only
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_set_na_sg_grid_user_password_pass(self, mock_request):
         args = self.set_args_create_na_sg_grid_user_with_password()
         args["update_password"] = "always"
@@ -454,16 +406,12 @@ class TestMyModule(unittest.TestCase):
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
-        print(
-            "Info: test_set_na_sg_grid_user_password_pass: %s" % repr(exc.value.args[0])
-        )
+        print("Info: test_set_na_sg_grid_user_password_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
     # attempt to set password on federated user
 
-    @patch(
-        "ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request"
-    )
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_fail_set_federated_user_password(self, mock_request):
         with pytest.raises(AnsibleFailJson) as exc:
             args = self.set_args_create_na_sg_grid_user_with_password()
@@ -471,6 +419,4 @@ class TestMyModule(unittest.TestCase):
             args["update_password"] = "always"
             set_module_args(args)
             grid_user_module()
-        print(
-            "Info: test_fail_set_federated_user_password: %s" % repr(exc.value.args[0])
-        )
+        print("Info: test_fail_set_federated_user_password: %s" % repr(exc.value.args[0]))
